@@ -1,6 +1,6 @@
 /*
- * $Id: common.h,v 1.2 1998/06/16 18:21:23 ams Exp $
- * Copyright 1998 ams@wiw.org (Abhijit Menon-Sen)
+ * $Id: common.h,v 1.7 2001/02/19 10:06:17 ams Exp $
+ * Copyright 1998-2001 Abhijit Menon-Sen <ams@wiw.org>
  */
 
 #include <ctype.h>
@@ -16,19 +16,22 @@
 
 #include "global.h"
 
-/* maximum line length in configuration file */
+/* Maximum line length in configuration file */
 #define MAXLINE 80
 
 #define MTU 4352
 
-/* command line parameters */
+/* Command line parameters */
 static struct option par[]={ {"file", 1, 0, 0},
                              {"no-resolve", 0, 0, 0},
                              {"version", 0, 0, 0},
                              {0, 0, 0, 0}
                            };
 
-/* functions in common.c */
+/* Convert IP addresses to hostnames? */
+short int resolve_names = 1;
+
+/* Functions defined in common.c */
 
 extern int background(void);
 extern int excepted(unsigned long int addr, char *str);
