@@ -1,8 +1,9 @@
 /*
- * $Id: icmplog.c,v 1.6 1998/08/03 14:09:36 ams Exp $
- * Copyright 1998 ams@wiw.org (Abhijit Menon-Sen)
+ * $Id: icmplog.c,v 1.7 2001/02/19 10:06:17 ams Exp $
+ * Copyright 1998-2001 Abhijit Menon-Sen <ams@wiw.org>
  */
 
+#include <string.h>
 #include "icmplog.h"
 
 #define ICMP_FILTER 1
@@ -60,7 +61,7 @@ void configure(char *file)
         if (strcasecmp(keyword, "except") == 0) {
             while ((name = strtok((char *)NULL, " \t\n,")) != (char *)NULL) {
                 /* add to list */
-                curr->host = (char *)malloc(strlen(name));
+                curr->host = (char *)malloc(strlen(name)+1);
                 if (curr->host == (char *)NULL) {
                     fprintf(stderr, "malloc() failed.\n");
                     exit(-1);
