@@ -1,6 +1,6 @@
 /*
- * $Id: icmplog.h,v 1.5 1998/08/03 13:53:28 ams Exp $
- * Copyright 1998 ams@wiw.org (Abhijit Menon-Sen)
+ * $Id: icmplog.h,v 1.7 2001/02/19 10:06:17 ams Exp $
+ * Copyright 1998-2001 Abhijit Menon-Sen <ams@wiw.org>
  */
 
 #include "common.h"
@@ -12,13 +12,10 @@
 char *version = "icmplog " VERSION ", ams@wiw.org";
 char *cfgfile = ICMPLOG_CONF;
 
-/* convert IP addresses to hostnames? */
-short int resolve_names = 1;
-
-/* default log level */
+/* Default log level */
 short int lvl = LOG_WARNING;
 
-/* default logging facility */
+/* Default logging facility */
 short int fac = LOG_DAEMON;
 
 /* ICMP packet */
@@ -28,7 +25,7 @@ typedef struct {
     char data[0];
 } icmppkt;
 
-/* level at which each packet is logged */
+/* Level at which each packet is logged */
 short int levels[256];
 
 typedef struct {
@@ -36,7 +33,7 @@ typedef struct {
     int type;
 } tname;
 
-/* configuration file type keywords */
+/* Configuration file type keywords */
 tname names[] = { { "echoreply", 0 },
                   { "destunreach", 3 },
                   { "quench", 4 },
