@@ -1,6 +1,6 @@
 /*
- * $Id: tcplog.h,v 1.5 1998/08/03 14:09:36 ams Exp $
- * Copyright 1998 ams@wiw.org (Abhijit Menon-Sen)
+ * $Id: tcplog.h,v 1.7 2001/02/19 10:06:17 ams Exp $
+ * Copyright 1998-2001 Abhijit Menon-Sen <ams@wiw.org>
  */
 
 #include "common.h"
@@ -14,13 +14,10 @@
 char *version = "tcplog " VERSION ", ams@wiw.org";
 char *cfgfile = TCPLOG_CONF;
 
-/* convert IP addresses to hostnames? */
-short int resolve_names = 1;
-
-/* default log level */
+/* Default log level */
 short int lvl = LOG_WARNING;
 
-/* default logging facility */
+/* Default logging facility */
 short int fac = LOG_DAEMON;
 
 /* TCP packet */
@@ -30,5 +27,5 @@ typedef struct {
     char data[0];
 } tcppkt;
 
-/* service list */
+/* Service list */
 char *ports[1024];
